var scopeName = "source.cobol";
var patterns = [
	{
		include: "#comment-line"
	},
	{
		include: "#comment-floating"
	},
	{
		include: "#number-constant"
	},
	{
		include: "#string-quoted-constant"
	},
	{
		include: "#string-double-quoted-constant"
	},
	{
		include: "#picture"
	},
	{
		include: "#sql-block"
	},
	{
		include: "#cics-block"
	},
	{
		include: "#cobol-keywords"
	},
	{
		include: "#cobol-preprocessor-keywords"
	},
	{
		include: "#idms-keywords"
	}
];
var repository = {
	"comment-line": {
		match: "^(.{6})(\\*.*)$",
		captures: {
			"1": {
				name: "constant.numeric.integer"
			},
			"2": {
				name: "comment.line.cobol.fixed"
			}
		}
	},
	"comment-floating": {
		match: "\\s\\*>\\s.*",
		name: "comment.line.cobol.floating"
	},
	"number-constant": {
		match: "(?<![\\+\\-\\w])(\\+|\\-)?\\d+(\\.\\d+)?([Ee](\\-|\\+)\\d+)?(?![\\-\\w])",
		name: "constant.numeric.integer"
	},
	"string-quoted-constant": {
		begin: "'",
		end: "'|$",
		name: "string.quoted.single.cobol"
	},
	"string-double-quoted-constant": {
		begin: "\"",
		end: "\"|$",
		name: "string.quoted.double.cobol"
	},
	picture: {
		match: "(?i:\\b(picture|pic)\\s+(is\\s+)?\\S+)(?<!\\.)",
		name: "storage.type.picture.cobol"
	},
	"cobol-keywords": {
		match: "(?<![\\-\\w])(?i:ABD|ABORT|ACCEPT|ACCESS|ADATA|ADD|ADDRESS|ADEXIT|ADV|ADVANCING|ADX|AFP|AFTER|ALIAS|ALL|ALPHABET|ALPHABETIC|ALPHABETIC-LOWER|ALPHABETIC-UPPER|ALPHANUMERIC|ALPHANUMERIC-EDITED|ALPHNUM|ALSO|ALTER|ALTERNATE|AND|ANSI|ANY|APOST|APPLY|AR|ARCH|ARE|AREA|AREAS|ARITH|ASCENDING|ASCII|ASSIGN|ASSOCIATED_DATA|ASSOCIATED_DATA_LENGTH|AT|AUTHOR|AUTO|AWO|BEFORE|BIN|BINARY|BLANK|BLOCK|BLOCK0|BOTTOM|BUF|BUFSIZE|BY|BYFUNCTION|BYTITLE|CALL|CANCEL|CAPABLE|CBL|CCSVERSION|CHAINING|CHANGED|CHANNEL|CHARACTER|CHARACTERS|CICS|CLASS|CLEANSIGN|CLOCK-UNITS|CLOSE|CLOSE-DISPOSITION|CO|CODEPAGE|CODE-SET|COLLATING|COMMA|COMMITMENT|COMMON|COMP|COMPAT|COMPILE|COMPUTATIONAL|COMPUTATIONAL-1|COMPUTATIONAL-2|COMPUTATIONAL-3|COMPUTATIONAL-4|COMPUTATIONAL-5|COMPUTE|COMP-1|COMP-2|COMP-3|COMP-4|COMP-5|CONFIGURATION|CONTAINS|CONTENT|CONTINUE|CONTROL|CONVERTING|COPYLOC|COPYRIGHT|CORR|CORRESPONDING|COUNT|CP|CPLC|CPYR|CR|CRUNCH|CS|CURR|CURRENCY|DATA|DATE|DATE-COMPILED|DATE-WRITTEN|DAY|DAY-OF-WEEK|DB|DBCS|DEBUGGING|DEBUG-CONTENTS|DEBUG-ITEM|DEBUG-LINE|DEBUG-NAME|DEBUG-SUB-1|DEBUG-SUB-2|DEBUG-SUB-3|DEC|DECIMAL-POINT|DECK|DECLARATIVES|DEF|DEFAULT|DEFAULT-DISPLAY|DEFINE|DEFINITION|DELETE|DELIMITED|DELIMITER|DEPENDING|DESCENDING|DFHRESP|DFHVALUE|DIAGTRUNC|DISABLE|DISK|DISPLAY|DISPLAY-1|DISPSIGN|DIVIDE|DIVISION|DLL|DN|DOWN|DS|DSN|DSNAME|DTR|DU|DUMP|DUPLICATES|DWARF|DYN|DYNAM|DYNAMIC|EBCDIC|EGCS|EGI|EJPD|ELSE|EMI|EN|ENABLE|ENCODING|END|ENDP|ENDPERIOD|END-ACCEPT|END-ADD|END-CALL|END-COMPUTE|END-DELETE|END-DIVIDE|END-EVALUATE|END-EXEC|END-IF|END-MULTIPLY|END-OF-PAGE|END-PERFORM|END-READ|END-RECEIVE|END-RETURN|END-REWRITE|END-SEARCH|END-START|END-STRING|END-SUBTRACT|END-UNSTRING|END-WRITE|END-XML|ENGLISH|ENTRY|ENVIRONMENT|EOC|EODS|EOP|EQUAL|ERROR|ESCAPE|ESI|EVALUATE|EVENP|EVENPACK|EVERY|EX|EXCEPTION|EXCLUSIVE|EXEC|EXHIBIT|EXIT|EXP|EXPORTALL|EXTEND|EXTERNAL|FALSE|FASTSRT|FD|FIELD|FILE|FILE-CONTROL|FILLER|FIRST|FLAG|FLAGSTD|FNC|FOOTING|FOR|FORCENUMCMP|FROM|FSRT|FULL|FUNCTION|FUNCTION-POINTER|GENERATE|GIVING|GLOBAL|GO|GOBACK|GREATER|GROUP-USAGE|HEX|HGPR|HIGH-VALUE|HIGH-VALUES|IC|ID|IDENTIFICATION|IF|IMPLICIT|IN|INDEX|INDEXED|INEXIT|INITCHECK|INITIAL|INITIALIZE|INITIATE|INL|INLINE|INPUT|INPUT-OUTPUT|INSPECT|INSTALLATION|INTDATE|INTEGER|INTO|INVALID|INVD|INVDATA|INVMPSZ|INVPARTN|INVREQ|INX|IS|I-O|I-O-CONTROL|JA|JAPANESE|JNIENVPTR|JP|JUST|JUSTIFIED|KANJI|KEPT|KEY|KEYBOARD|LABEL|LANG|LANGUAGE|LAST|LAX|LAXPERF|LAXREDEF|LC|LEADING|LEFT|LENGTH|LESS|LIBEXIT|LIBRARY|LIBX|LILIAN|LIMIT|LINAGE|LINAGE-COUNTER|LINE|LINECOUNT|LINES|LINE-COUNTER|LINKAGE|LIST|LM|LOCAL|LOCAL-STORAGE|LOCK|LONGMIXED|LONGUPPER|LOW-VALUE|LOW-VALUES|LP|LU|LXPRF|LXRDF|MAP|MAPFAIL|MAXPCF|MD|MDECK|MEMORY|MERGE|MESSAGE|MIG|MIXED|MMDDYYYY|MODE|MODULES|MOVE|MSG|MSGEXIT|MSGX|MULTIPLE|MULTIPLY|NAME|NAMED|NAT|NATIONAL|NATIONAL-EDITED|NATIVE|NC|ND|NEGATIVE|NETWORK|NEXT|NO|NOADATA|NOADEXIT|NOADV|NOADX|NOALIAS|NOALPHNUM|NOAWO|NOBIN|NOBLOCK0|NOC|NOCICS|NOCLEANSIGN|NOCOMPILE|NOCOPYLOC|NOCOPYRIGHT|NOCPLC|NOCPYR|NOCS|NOCURR|NOCURRENCY|NOD|NODBCS|NODECK|NODEF|NODEFINE|NODIAGTRUNC|NODLL|NODSNAME|NODTR|NODU|NODUMP|NODWARF|NODYN|NODYNAM|NOEJPD|NOENDPERIOD|NOEVENPACK|NOEX|NOEXIT|NOEXP|NOEXPORTALL|NOF|NOFASTSRT|NOFLAG|NOFLAGSTD|NOFNC|NOFORCENUMCMP|NOFSRT|NOIC|NOINEXIT|NOINITCHECK|NOINITIAL|NOINL|NOINLINE|NOINVD|NOINVDATA|NOINX|NOLAXPERF|NOLAXREDEF|NOLIBEXIT|NOLIBX|NOLIST|NOMAP|NOMD|NOMDECK|NOMSGEXIT|NOMSGX|NONAME|NONC|NONUM|NONUMBER|NONUMCHECK|NOOBJ|NOOBJECT|NOOFF|NOOFFSET|NOOMITODOMIN|NOPAC|NOPARMCHECK|NOPC|NOPFD|NOPRESERVE|NOPRTEXIT|NOPRTX|NORENT|NORULES|NOS|NOSEP|NOSEPARATE|NOSEQ|NOSEQUENCE|NOSERV|NOSERVICE|NOSLACKBYTES|NOSO|NOSOURCE|NOSQL|NOSQLC|NOSQLCCSID|NOSQLIMS|NOSSR|NOSSRANGE|NOSTGOPT|NOSUPP|NOSUPPRESS|NOT|NOTERM|NOTERMINAL|NOTEST|NOTHREAD|NOTRUNCBIN|NOUNRA|NOUNREFALL|NOUNREFSOURCE|NOUNRS|NOVBREF|NOVOLATILE|NOWD|NOWORD|NOX|NOXREF|NOZC|NOZLEN|NOZON|NOZONECHECK|NOZWB|NS|NSYMBOL|NULL|NULLS|NUM|NUMBER|NUMCHECK|NUMERIC|NUMERIC-EDITED|NUMPROC|OBJ|OBJECT|OBJECT-COMPUTER|OCCURS|ODT|OF|OFF|OFFSET|OMITODOMIN|OMITTED|ON|OOM|OPEN|OPT|OPTFILE|OPTIMIZE|OPTIONAL|OR|ORDER|ORDERLY|ORGANIZATION|OTHER|OUT|OUTDD|OUTPUT|OVERFLOW|PAC|PACKED-DECIMAL|PADDING|PAGE|PAGE-COUNTER|PARMCHECK|PARSE|PARTNFAIL|PASSWORD|PATH|PC|PERFORM|PFD|PGMN|PGMNAME|PIC|PICTURE|POINTER|POINTER-32|PORT|POSITION|POSITIVE|PRESERVE|PRINTER|PROCEDURE|PROCEDURES|PROCEDURE-POINTER|PROCEED|PROCESS|PROCESSING|PROGRAM|PROGRAM-ID|PRTEXIT|PRTX|PURGE|QUA|QUALIFY|QUOTE|QUOTES|RANDOM|RDATT|READ|READER|READY|RECEIVE|RECORD|RECORDING|RECORDS|RECURSIVE|REDEFINES|REEL|REFERENCE|REFERENCES|RELATIVE|RELEASE|RELOAD|REMAINDER|REMARKS|REMOTE|REMOVAL|REMOVE|RENAMES|RENT|REPLACING|REPORT|REPORTS|RERUN|RESERVE|RESET|RESUME|RETURN|RETURNING|RETURN-CODE|REVERSED|REWIND|REWRITE|RIGHT|RMODE|ROUNDED|RULES|RUN|SAME|SAVE|SD|SEARCH|SECTION|SECURITY|SEGMENT|SEGMENT-LIMIT|SELECT|SEND|SENTENCE|SEP|SEPARATE|SEQ|SEQUENCE|SEQUENTIAL|SERV|SERVICE|SET|SHIFT-IN|SHIFT-OUT|SHORT|SIGN|SIZE|SLACKBYTES|SLCKB|SN|SO|SORT|SORT-CONTROL|SORT-CORE-SIZE|SORT-FILE-SIZE|SORT-MERGE|SORT-MESSAGE|SORT-MODE-SIZE|SORT-RETURN|SOURCE|SOURCE-COMPUTER|SPACE|SPACES|SPECIAL-NAMES|SQL|SQLC|SQLCCSID|SQLIMS|SSR|SSRANGE|STANDARD|STANDARD-1|STANDARD-2|START|STATUS|STD|STGOPT|STOP|STRICT|STRING|SUBTRACT|SUCC|SUM|SUPP|SUPPRESS|SYMBOL|SYMBOLIC|SYNC|SYNCHRONIZED|SYSLIB|TALLY|TALLYING|TAPE|TERM|TERMINAL|TERMINATE|TEST|THAN|THEN|THREAD|THROUGH|THRU|TIME|TIMER|TIMES|TO|TODAYS-DATE|TODAYS-NAME|TOP|TRACE|TRAILING|TRUE|TRUNC|TRUNCBIN|TUNE|UE|UENGLISH|UNEXPIN|UNIT|UNREF|UNSTRING|UNTIL|UP|UPON|UPPER|USAGE|USE|USING|UTF-8|VALIDATING|VALUE|VALUES|VARYING|VBREF|VIRTUAL|VLR|VOLATILE|VS|VSAMOPENFS|WAIT|WD|WHEN|WHEN-COMPILED|WITH|WORD|WORDS|WORKING-STORAGE|WRITE|WRITE-ONLY|XML|XMLPARSE|XMLSS|XP|XREF|YEAR|YYYYDDD|YYYYMMDD|ZC|ZD|ZERO|ZEROES|ZEROS|ZLEN|ZON|ZONECHECK|ZONEDATA|ZWB)(?![\\-\\w])",
		name: "keyword.cobol"
	},
	"idms-keywords": {
		match: "(?<![\\-\\w])(?i:ABEND|ABORT|ACCEPT|ACTIVE|ADDRESS|AID|ALARM|ALL|ALPHANUMERIC|ALWAYS|ANY|AREA|AT|ATTACH|ATTRIBUTE|ATTRIBUTES|AUTODISPLAY|BACKPAGE|BACKSCAN|BELOW|BIND|BLINK|BLUE|BRIGHT|BROWSE|BUFFER|BUT|BY|CALC|CANCEL|CHANGE|CHANGED|CHECK|CLASS|CLEAR|CODE|COMMIT|COMP-3|COMP|CONNECT|CONTENTS|CONTINUE|CONTROL|COPIES|CORRECT|CR|CURRENCY|CURRENT|CURSOR|DARK|DATA|DATASTREAM|DATE|DAY|DAY-OF-WEEK|DB|DB-KEY|DBNAME|DBNODE|DC|DEBUG-CONTENTS|DEBUG|DEBUG-ITEM|DEBUG-LINE|DEBUG-NAME|DEBUG-SUB-1|DEBUG-SUB-2|DEBUG-SUB-3|DELETE|DEQUEUE|DEST|DESTINATION|DETAIL|DETECT|DFLD|DICTNAME|DICTNODE|DIFFERENT|DISCONNECT|DISPLAY|DUMP|DUPLICATE|EAU|ECHO|EDIT|EMPTY|END|ENDPAGE|ENDRPT|ENQUEUE|ERASE|ERROR|EVENT|EXCEPT|EXCLUSIVE|EXIT|EXITS|EXTENDED|EXTERNAL|EXTRANEOUS|FALSE|FIELD|FIELDS|FIND|FINISH|FIRST|FOR|FREE|FROM|FUNCTION|GET|GREEN|HEADER|HIGH-VALUE|HIGH-VALUES|HOLD|IDENTICAL|ID|IDMS-CONTROL|IDMS-RECORDS|IDMS-STATISTICS|IF|IGNORED|IMMEDIATE|INCREMENTED|IN|INPUT|INQUIRE|INTEGER|INTERNAL|INTERVAL|INTO|INVOKED|IO|IS|JNIENVPTR|JOURNAL|JUSTIFY|KEEP|KEY|LAST|LEFT|LENGTH|LEVELS|LINAGE-COUNTER|LINE-COUNTER|LINE|LINKAGE|LINK|LIST|LITERALS|LOADLIB|LOAD|LOCATION|LOCK|LOG|LONG|LONGTERM|LOW-VALUE|LOW-VALUES|LTERM|MANUAL|MAP|MAX|MDT|MEMBER|MEMBERS|MESSAGE|MODE|MODIFIED|MODIFY|MOVE|NAME|NATIVE|NEW|NEWPAGE|NEXT|NLCR|NOALARM|NOAUTODISPLAY|NOBACKPAGE|NOBACKSCAN|NOBLINK|NOCOLOR|NODEADLOCK|NODENAME|NODUMP|NOIO|NOKBD|NOLOCK|NOMDT|NONE|NO|NOPRT|NORETURN|NORMAL|NORMAL-VIDEO|NOSPAN|NOTIFICATION|NOTIFY|NOT|NOUNDERSCORE|NOWAIT|NOWRITE|NULL|NULLS|NUMBER|NUMERIC|OBTAIN|OFF|OF|ONLY|ON|OPTIONAL|OUTIN|OUT|OUTPUT|OWNER|PAD|PAGE-COUNTER|PAGE-INFO|PAGE|PAGING|PARMS|PERMANENT|PINK|POINTER|POSITION|POST|PREFIX|PRINTER|PRIORITY|PRIOR|PROCEDURE|PROGRAM|PROTECTED|PROTOCOL|PTERM|PUT|QUEUE|QUOTE|QUOTES|RANDOM|READ|READY|RECORD|REDISPATCH|RED|RELEASE|REPLACE|REPLY|REPORT|REQUIRED|RESETKBD|RESETMDT|RESUME|RETENTION|RETRIEVAL|RETURN-CODE|RETURNKEY|RETURN|REVERSE-VIDEO|RIGHT|ROLLBACK|RUN-UNIT|SCHEMA|SCRATCH|SCREEN|SCREENSIZE|SECONDS|SECTION|SELECTIVE|SEND|SEQUENCE|SESSION|SET|SHARED|SHARE|SHIFT-IN|SHIFT-OUT|SHORT|SKIP|SNAP|SOME|SORT-CONTROL|SORT-CORE-SIZE|SORT-FILE-SIZE|SORT-MESSAGE|SORT-MODE-SIZE|SORT-RETURN|SPACE|SPACES|SPAN|STANDARD|STARTPAGE|STARTPRT|START|STATISTICS|STGID|STORAGE|STORE|SUBSCHEMA-NAMES|SUM|SUPPRESS|SYSTEM|SYSVERSION|TABLE|TALLY|TASK|TEMPORARY|TERMINAL|TEST|TEXT|THEN|TIMEOUT|TIMER|TIME|TITLE|TO|TRANSACTION|TRANSFER|TRUE|TRUNCATED|TURQUOISE|TYPE|UNDERSCORE|UNFORMATTED|UNPROTECTED|UPDATE|UPGRADE|USAGE-MODE|USER|USING|VALUE|VERSION|WAIT|WCC|WHEN-COMPILED|WHITE|WITHIN|WITH|WORKING-STORAGE|WRITE|XCTL|YELLOW|YES|ZEROES|ZEROS|ZERO)(?![\\-\\w])",
		name: "keyword.idms"
	},
	"cics-keywords": {
		match: "(?<![\\-\\w])(?i:ABCODE|ABDUMP|ABEND|ABORT|ABPROGRAM|ABSTIME|ACCUM|ACEE|ACQACTIVITY|ACQPROCESS|ACQUACTIVITY|ACTION|ACTIVITY|ACTIVITYID|ACTPARTN|ADD|ADDRESS|AFTER|AID|ALARM|ALL|ALLOCATE|ALTER|ALTERNATE|ALTSCRNHT|ALTSCRNWD|AND|ANYKEY|APLKYBD|APLTEXT|APPLID|AS|ASA|ASIS|ASKTIME|ASRAINTRPT|ASRAKEY|ASRAPSW|ASRAREGS|ASRASPC|ASRASTG|ASSIGN|ASYNCHRONOUS|AT|ATTACH|ATTACHID|ATTRIBUTES|AUTHENTICATE|AUTOPAGE|AUXILIARY|BASE64|BASICAUTH|BELOW|BIF|BINARY|BIT|BODYCHARSET|BOOKMARK|BRDATA|BRDATALENGTH|BREXIT|BRIDGE|BROWSETOKEN|BTRANS|BUFFER|BUILD|BURGEABILITY|CADDRLENGTH|CANCEL|CARD|CBUFF|CCSID|CERTIFICATE|CHANGE|CHANGETIME|CHANNEL|CHAR|CHARACTERSET|CHECK|CHUNKEND|CHUNKING|CHUNKNO|CHUNKYES|CICSDATAKEY|CIPHERS|CLASS|CLEAR|CLICONVERT|CLIENT|CLIENTADDR|CLIENTADDRNU|CLIENTCONV|CLIENTNAME|CLNTADDR6NU|CLNTIPFAMILY|CLOSE|CLOSESTATUS|CLRPARTN|CMDSEC|CNAMELENGTH|CNOTCOMPL|CODEPAGE|COLOR|COMMAREA|COMMONNAME|COMMONNAMLEN|COMPAREMAX|COMPAREMIN|COMPLETE|COMPOSITE|COMPSTATUS|CONDITION|CONFIRM|CONFIRMATION|CONNECT|CONSISTENT|CONSOLE|CONTAINER|CONTEXTTYPE|CONTROL|CONVDATA|CONVERSE|CONVERTST|CONVERTTIME|CONVID|COPY|COUNTER|COUNTRY|COUNTRYLEN|CREATE|CRITICAL|CTLCHAR|CURRENT|CURSOR|CWA|CWALENG|DATA|DATA1|DATA2|DATALENGTH|DATALENTH|DATAONLY|DATAPOINTER|DATASET|DATASTR|DATATOXML|DATATYPE|DATCONTAINER|DATE|DATEFORM|DATESEP|DATESTRING|DAY|DAYCOUNT|DAYOFMONTH|DAYOFWEEK|DAYOFYEAR|DAYS|DAYSLEFT|DAY-OF-WEEK|DCOUNTER|DDMMYY|DDMMYYYY|DEBKEY|DEBREC|DEBUG-CONTENTS|DEBUG-ITEM|DEBUG-LINE|DEBUG-NAME|DEBUG-SUB-1|DEBUG-SUB-2|DEBUG-SUB-3|DEEDIT|DEFAULT|DEFINE|DEFRESP|DEFSCRNHT|DEFSCRNWD|DELAY|DELETE|DELETEQ|DELIMITER|DEQ|DESTCOUNT|DESTID|DESTIDLENG|DETAIL|DETAILLENGTH|DFHRESP|DFHVALUE|DIGEST|DIGESTTYPE|DISCONNECT|DOCDELETE|DOCSIZE|DOCSTATUS|DOCTOKEN|DOCUMENT|DS3270|DSSCS|DUMP|DUMPCODE|DUMPID|DUPREC|ECADDR|ECBLIST|EIB|ELEMNAME|ELEMNAMELEN|ELEMNS|ELEMNSLEN|END|ENDACTIVITY|ENDBR|ENDBROWSE|ENDFILE|ENDOUTPUT|ENQ|ENTER|ENTRY|ENTRYNAME|EOC|EODS|EPRFIELD|EPRFROM|EPRINTO|EPRLENGTH|EPRSET|EPRTYPE|EQUAL|ERASE|ERASEAUP|ERROR|ERRTERM|ESMREASON|ESMRESP|EVENT|EVENTTYPE|EVENTUAL|EWASUPP|EXCEPTION|EXPECT|EXPIRYTIME|EXTDS|EXTERNAL|EXTRACT|FACILITY|FACILITYTOKN|FALSE|FAULTACTLEN|FAULTACTOR|FAULTCODE|FAULTCODELEN|FAULTCODESTR|FAULTSTRING|FAULTSTRLEN|FCI|FCT|FIELD|FILE|FIRESTATUS|FLENGTH|FMH|FMHPARM|FOR|FORCE|FORMATTIME|FORMFEED|FORMFIELD|FREE|FREEKB|FREEMAIN|FROM|FROMACTIVITY|FROMCCSID|FROMCHANNEL|FROMCODEPAGE|FROMDOC|FROMFLENGTH|FROMLENGTH|FROMPROCESS|FRSET|FULLDATE|FUNCTION|GCHARS|GCODES|GDS|GENERIC|GET|GETMAIN|GETNEXT|GMMI|GROUPID|GTEC|GTEQ|HANDLE|HEAD|HEADER|HEX|HIGH-VALUE|HIGH-VALUES|HILIGHT|HOLD|HONEOM|HOST|HOSTCODEPAGE|HOSTLENGTH|HOSTTYPE|HOURS|HTTPHEADER|HTTPMETHOD|HTTPRNUM|HTTPVERSION|HTTPVNUM|IGNORE|IMMEDIATE|IN|INCREMENT|INITIMG|INITPARM|INITPARMLEN|INPARTN|INPUT|INPUTEVENT|INPUTMSG|INPUTMSGLEN|INQUIRE|INSERT|INTEGER|INTERVAL|INTO|INTOCCSID|INTOCODEPAGE|INVALIDCOUNT|INVITE|INVMPSZ|INVOKE|INVOKINGPROG|INVPARTN|INVREQ|ISSUE|ISSUER|ITEM|IUTYPE|JOURNALNAME|JTYPEID|JUSFIRST|JUSLAST|JUSTIFY|KATAKANA|KEEP|KEYLENGTH|KEYNUMBER|L40|L64|L80|LABEL|LANGINUSE|LANGUAGECODE|LAST|LASTUSETIME|LDC|LDCMNEM|LDCNUM|LEAVEKB|LENGTH|LENGTHLIST|LEVEL|LIGHTPEN|LINAGE-COUNTER|LINE|LINEADDR|LINE-COUNTER|LINK|LIST|LISTLENGTH|LLID|LOAD|LOCALITY|LOCALITYLEN|LOGMESSAGE|LOGMODE|LOGONLOGMODE|LOGONMSG|LOW-VALUE|LOW-VALUES|LUNAME|MAIN|MAP|MAPCOLUMN|MAPFAIL|MAPHEIGHT|MAPLINE|MAPONLY|MAPPED|MAPPINGDEV|MAPSET|MAPWIDTH|MASSINSERT|MAXDATALEN|MAXFLENGTH|MAXIMUM|MAXLENGTH|MAXLIFETIME|MAXPROCLEN|MCC|MEDIATYPE|MESSAGE|MESSAGEID|METADATA|METADATALEN|METHOD|METHODLENGTH|MILLISECONDS|MINIMUM|MINUTES|MMDDYY|MMDDYYYY|MODE|MODENAME|MONITOR|MONTH|MONTHOFYEAR|MOVE|MSR|MSRCONTROL|NAME|NAMELENGTH|NATLANG|NATLANGINUSE|NETNAME|NEWPASSWORD|NEWPHRASE|NEWPHRASELEN|NEXT|NEXTTRANSID|NLEOM|NOAUTOPAGE|NOCC|NOCHECK|NOCLICONVERT|NOCLOSE|NODATA|NODE|NODOCDELETE|NODUMP|NOEDIT|NOFLUSH|NOHANDLE|NOINCONVERT|NONE|NOOUTCONERT|NOQUEUE|NOQUIESCE|NOSRVCONVERT|NOSUSPEND|NOTE|NOTPURGEABLE|NOTRUNCATE|NOWAIT|NSCONTAINER|NULL|NULLS|NUMCIPHERS|NUMEVENTS|NUMITEMS|NUMREC|NUMROUTES|NUMSEGMENTS|NUMTAB|OF|OIDCARD|ON|OPCLASS|OPEN|OPERATION|OPERATOR|OPERID|OPERKEYS|OPERPURGE|OPID|OPSECURITY|OPTIONS|OR|ORGABCODE|ORGANIZATION|ORGANIZATLEN|ORGUNIT|ORGUNITLEN|OUTDESCR|OUTLINE|OUTPARTN|OUTPUT|OWNER|PA1|PA2|PA3|PAGE|PAGENUM|PAGE-COUNTER|PAGING|PARSE|PARTN|PARTNER|PARTNFAIL|PARTNPAGE|PARTNS|PARTNSET|PASS|PASSBK|PASSWORD|PASSWORDLEN|PATH|PATHLENGTH|PCT|PF1|PF10|PF11|PF12|PF13|PF14|PF15|PF16|PF17|PF18|PF19|PF2|PF20|PF21|PF22|PF23|PF24|PF3|PF4|PF5|PF6|PF7|PF8|PF9|PFXLENG|PHRASE|PHRASELEN|PIPLENGTH|PIPLIST|POINT|POOL|POP|PORTNUMBER|PORTNUMNU|POST|PPT|PREDICATE|PREFIX|PREPARE|PRINCONVID|PRINSYSID|PRINT|PRIORITY|PRIVACY|PROCESS|PROCESSTYPE|PROCLENGTH|PROCNAME|PROFILE|PROGRAM|PROTECT|PS|PUNCH|PURGE|PURGEABLE|PUSH|PUT|QNAME|QUERY|QUERYPARM|QUERYSTRING|QUERYSTRLEN|QUEUE|QUOTE|QUOTES|RANDOM|RBA|RBN|RDATT|READ|READNEXT|READPREV|READQ|REATTACH|RECEIVE|RECEIVER|RECFM|RECORD|RECORDLEN|RECORDLENGTH|REDUCE|REFPARMS|REFPARMSLEN|RELATESINDEX|RELATESTYPE|RELATESURI|RELEASE|REMOVE|REPEATABLE|REPETABLE|REPLACE|REPLY|REPLYLENGTH|REQID|REQUESTTYPE|RESCLASS|RESET|RESETBR|RESID|RESIDLENGTH|RESOURCE|RESP|RESP2|RESSEC|RESTART|RESTYPE|RESULT|RESUME|RETAIN|RETCODE|RETCORD|RETRIECE|RETRIEVE|RETURN|RETURNPROG|RETURN-CODE|REWIND|REWRITE|RIDFLD|ROLE|ROLELENGTH|ROLLBACK|ROUTE|ROUTECODES|RPROCESS|RRESOURCE|RRN|RTERMID|RTRANSID|RUN|SADDRLENGTH|SCHEME|SCHEMENAME|SCOPE|SCOPELEN|SCRNHT|SCRNWD|SECONDS|SECURITY|SEGMENTLIST|SEND|SENDER|SERIALNUM|SERIALNUMLEN|SERVER|SERVERADDR|SERVERADDRNU|SERVERCONV|SERVERNAME|SERVICE|SESSION|SESSTOKEN|SET|SHARED|SHIFT-IN|SHIFT-OUT|SIGDATA|SIGNAL|SIGNOFF|SIGNON|SIT|SNAMELENGTH|SOAPFAULT|SORT-CONTROL|SORT-CORE-SIZE|SORT-FILE-SIZE|SORT-MESSAGE|SORT-MODE-SIZE|SORT-RETURN|SOSI|SPACE|SPACES|SPOOLCLOSE|SPOOLOPEN|SPOOLREAD|SPOOLWRITE|SRVCONVERT|SRVRADDR6NU|SRVRIPFAMILY|SSLTYPE|START|STARTBR|STARTBROWSE|STARTCODE|STATE|STATELEN|STATIONID|STATUS|STATUSCODE|STATUSLEN|STATUSTEXT|STORAGE|STRFIELD|STRINGFORMAT|SUBADDR|SUBCODELEN|SUBCODESTR|SUBEVENT|SUBEVENT1|SUBEVENT2|SUBEVENT3|SUBEVENT4|SUBEVENT5|SUBEVENT6|SUBEVENT7|SUBEVENT8|SUM|SUSPEND|SUSPSTATUS|SYMBOL|SYMBOLLIST|SYNCHRONOUS|SYNCLEVEL|SYNCONRETURN|SYNCPOINT|SYSID|TABLES|TALLY|TASK|TASKPRIORITY|TCPIP|TCPIPSERVICE|TCT|TCTUA|TCTUALENG|TD|TELLERID|TEMPLATE|TERMCODE|TERMID|TERMINAL|TERMPRIORITY|TEST|TEXT|TEXTKYBD|TEXTLENGTH|TEXTPRINT|TIME|TIMEOUT|TIMER|TIMESEP|TITLE|TO|TOACTIVITY|TOCHANNEL|TOCONTAINER|TOFLENGTH|TOKEN|TOLENGTH|TOPROCESS|TRACE|TRACENUM|TRAILER|TRANPRIORITY|TRANSACTION|TRANSFORM|TRANSID|TRIGGER|TRT|TRUE|TS|TWA|TWALENG|TYPE|TYPENAME|TYPENAMELEN|TYPENS|TYPENSLEN|UNATTEND|UNCOMMITTED|UNESCAPED|UNEXPIN|UNLOCK|UNTIL|UOW|UPDATE|URI|URIMAP|URL|URLLENGTH|USERDATAKEY|USERID|USERNAME|USERNAMELEN|USERPRIORITY|USING|VALIDATION|VALUE|VALUELENGTH|VERIFY|VERSIONLEN|VOLUME|VOLUMELENG|WAIT|WAITCICS|WEB|WHEN-COMPILED|WPMEDIA1|WPMEDIA2|WPMEDIA3|WPMEDIA4|WRAP|WRITE|WRITEQ|WSACONTEXT|WSAEPR|XCTL|XMLCONTAINER|XMLTODATA|XMLTRANSFORM|XRBA|YEAR|YYDDD|YYDDMM|YYMMDD|YYYYDDD|YYYYDDMM|YYYYMMDD|ZERO|ZEROES|ZEROS)(?![\\-\\w])",
		name: "keyword.verb.cics"
	},
	"db2-sql-keywords": {
		match: "(?<![\\-\\w])(?i:ABSOLUTE|ACCELERATION|ACCELERATOR|ACCESS|ACCESSCTRL|ACCTNG|ACTION|ACTIVATE|ACTIVE|ADD|ADDRESS|AFTER|AGE|ALGORITHM|ALIAS|ALL|ALLOCATE|ALLOW|ALTER|ALTERIN|ALWAYS|AND|ANY|APPEND|APPLCOMPAT|APPLICATION|APPLNAME|ARCHIVE|ARRAY|ARRAY_EXISTS|AS|ASC|ASCII|ASENSITIVE|ASSEMBLE|ASSOCIATE|ASUTIME|AT|ATOMIC|ATTRIBUTES|AUDIT|AUTHENTICATION|AUTHID|AUTONOMOUS|AUX|AUXILIARY|AVG|BASED|BEFORE|BEGIN|BETWEEN|BIGINT|BINARY|BIND|BINDADD|BINDAGENT|BIT|BLOB|BOTH|BSDS|BUFFERPOOL|BUFFERPOOLS|BUSINESS_TIME|BY|CACHE|CALL|CALLED|CALLER|CAPTURE|CARDINALITY|CASCADE|CASCADED|CASE|CAST|CATALOG_NAME|CCSID|CHANGE|CHANGED|CHANGES|CHAR|CHARACTER|CHARACTER_LENGTH|CHAR_LENGTH|CHECK|CLAUSE|CLIENT|CLIENT_ACCTNG|CLIENT_APPLNAME|CLIENT_CORR_TOKEN|CLIENT_USERID|CLIENT_WRKSTNNAME|CLOB|CLONE|CLOSE|CLUSTER|COALESCE|COBOL|COLLECTION|COLLID|COLUMN|COLUMNS|COMMENT|COMMIT|COMMITTED|COMPATIBILITY|COMPRESS|CONCAT|CONCENTRATE|CONCURRENT|CONDITION|CONDITION_NUMBER|CONNECT|CONNECTION|CONSTANT|CONSTRAINT|CONTAINS|CONTEXT|CONTINUE|CONTROL|COPY|CORR|CORRELATION|COUNT|COUNT_BIG|COVARIANCE|CREATE|CREATEALIAS|CREATEDBA|CREATESG|CREATEIN|CREATESG|CREATETAB|CREATETMTAB|CREATETS|CREATE_SECURE_OBJECT|CROSS|CS|CUBE|CUME_DIST|CURRENT|CURRENTLY|CURRENT_DATE|CURRENT_LC_CTYPE|CURRENT_PATH|CURRENT_SCHEMA|CURRENT_SERVER|CURRENT_TIME|CURRENT_TIMESTAMP|CURRENT_TIMEZONE|CURSOR|CURSORS|CURSOR_NAME|CYCLE|DATA|DATAACCESS|DATABASE|DATACLAS|DATE|DAY|DAYOFMONTH|DAYOFWEEK|DAYOFYEAR|DAYS|DB2SQL|DB2_AUTHENTICATION_TYPE|DB2_AUTHORIZATION_ID|DB2_CONNECTION_STATE|DB2_CONNECTION_STATUS|DB2_ENCRYPTION_TYPE|DB2_ERROR_CODE1|DB2_ERROR_CODE2|DB2_ERROR_CODE3|DB2_ERROR_CODE4|DB2_GET_DIAGNOSTICS_DIAGNOSTICS|DB2_INTERNAL_ERROR_POINTER|DB2_LAST_ROW|DB2_LINE_NUMBER|DB2_MESSAGE_ID|DB2_MODULE_DETECTING_ERROR|DB2_NUMBER_PARAMETER_MARKERS|DB2_NUMBER_RESULT_SETS|DB2_NUMBER_ROWS|DB2_ORDINAL_TOKEN1|DB2_ORDINAL_TOKEN2|DB2_ORDINAL_TOKEN3|DB2_ORDINAL_TOKEN4|DB2_PRODUCT_ID|DB2_REASON_CODE|DB2_RETURNED_SQLCODE|DB2_RETURN_STATUS|DB2_ROW_NUMBER|DB2_SERVER_CLASS_NAME|DB2_SQLERRD1|DB2_SQLERRD2|DB2_SQLERRD3|DB2_SQLERRD4|DB2_SQLERRD5|DB2_SQLERRD6|DB2_SQLERRD_SET|DB2_SQL_ATTR_CURSOR_HOLD|DB2_SQL_ATTRCURSOR_ROWSET|DB2_SQL_ATTR_CURSOR_SCROLLABLE|DB2_SQL_ATTR_CURSOR_SENSITIVITY|DB2_SQL_ATTR_CURSOR_TYPE|DB2_SQL_NESTING_LEVEL|DB2_TOKEN_COUNT|DBADM|DBCLOB|DBCTRL|DBINFO|DBMAINT|DEACTIVATE|DEALLOCATE|DEBUG|DEBUGSESSION|DEC|DECFLOAT|DECIMAL|DECLARE|DEC_ROUND_CEILING|DEC_ROUND_DOWN|DEC_ROUND_FLOOR|DEC_ROUND_HALF_DOWN|DEC_ROUND_HALF_EVEN|DEC_ROUND_HALF_UP|DEC_ROUND_UP|DEFAULT|DEFAULTS|DEFER|DEFERRED|DEFINE|DEFINEBIND|DEFINER|DEFINERUN|DEGREE|DELETE|DENSE_RANK|DEPENDENT|DESC|DESCRIBE|DESCRIPTOR|DETERMINISTIC|DIAGNOSTICS|DISABLE|DISALLOW|DISPATCH|DISPLAY|DISPLAYDB|DISTINCT|DO|DOUBLE|DOUBLEQUOTE|DROP|DROPIN|DSNDB04|DSSIZE|DYNAMIC|DYNAMICRULES|EACH|EBCDIC|EDITPROC|ELEMENT|ELIGIBLE|ELSE|ELSEIF|EMPTY|ENABLE|ENCODING|ENCRYPTION|END|ENDING|ENFORCED|ENVIRONMENT|ERASE|ESCAPE|EUR|EVERY|EXCEPT|EXCHANGE|EXCLUDE|EXCLUDING|EXCLUSIVE|EXECUTE|EXISTS|EXIT|EXPLAIN|EXTERNAL|EXTRA|EXTRACT|FAILBACK|FAILURE|FAILURES|FENCED|FETCH|FIELDPROC|FINAL|FIRST|FIRST_VALUE|FLOAT|FOLLOWING|FOR|FOREIGN|FORMAT|FOUND|FREE|FREEPAGE|FROM|FULL|FUNCTION|V10R1|V11R1|GBPCACHE|GENERAL|GENERATE|GENERATED|GENERIC|GET|GET_ACCEL_ARCHIVE|GLOBAL|GO|GOTO|GRANT|GRAPHIC|GROUP|GROUPING|HANDLER|HASH|HAVING|HEX|HIDDEN|HINT|HISTORY|HOLD|HOUR|HOURS|ID|IDENTITY|IF|IGNORE|IMAGCOPY|IMMEDIATE|IMPLICITLY|IN|INCLUDE|INCLUDING|INCLUSIVE|INCREMENT|INDEX|INDEXBP|INDICATOR|INHERIT|INITIALLY|INLINE|INNER|INOUT|INPUT|INSENSITIVE|INSERT|INSTEAD|INT|INTEGER|INTERSECT|INTO|INVALID|INVOKEBIND|INVOKERUN|IS|ISO|ISOLATION|ITERATE|JAR|JAVA|JIS|JOBNAME|JOIN|KEEP|KEY|KEYS|LABEL|LABELS|LAG|LANGUAGE|LARGE|LAST|LAST_VALUE|LC_CTYPE|LEAD|LEAVE|LEFT|LENGTH|LEVEL|LIKE|LIMIT|LITERALS|LOAD|LOB|LOCAL|LOCALE|LOCATION|LOCATOR|LOCATORS|LOCK|LOCKED|LOCKMAX|LOCKS|LOCKSIZE|LOGGED|LOOP|LOWER|MAIN|MAINTAINED|MASK|MATCHED|MATERIALIZED|MAX|MAXPARTITIONS|MAXROWS|MAXVALUE|MEMBER|MERGE|MESSAGE_TEXT|MGMTCLAS|MICROSECOND|MICROSECONDS|MIN|MINUTE|MINUTES|MINVALUE|MIXED|MODE|MODIFIERS|MODIFIES|MONITOR1|MONITOR2|MONTH|MONTHS|MORE|MOVE|MULTIPLIER|NAME|NAMES|NAMESPACE|NATIONAL|NCNAME|NEW|NEW_TABLE|NEXT|NO|NODEFER|NONE|NOT|NTH_VALUE|NTILE|NULL|NULLS|NULTERM|NUMBER|NUMERIC|NUMPARTS|OBID|OBJECT|OF|OFF|OFFSET|OLD|OLD_TABLE|ON|ONCE|ONLY|OPEN|OPERATION|OPTHINT|OPTIMIZATION|OPTION|OPTIONAL|OPTIONS|OR|ORDER|ORDINALITY|ORGANIZE|ORIGINAL|OUT|OUTCOME|OUTER|OUTPUT|OVER|OVERLAPS|OVERRIDING|OWNER|OWNERSHIP|PACKADM|PACKAGE|PACKAGESET|PACKAGE_NAME|PACKAGE_SCHEMA|PACKAGE_VERSION|PADDED|PAGE|PAGENUM|PARALLEL|PARAMETER|PART|PARTITION|PARTITIONED|PASSING|PASSWORD|PATH|PCTFREE|PENDING|PERCENT_RANK|PERIOD|PERMISSION|PIECESIZE|PLAN|PLI|PORTION|POSITION|POSITIONING|PRECEDING|PRECISION|PREPARE|PRESERVE|PREVIOUS|PRIMARY|PRIOR|PRIQTY|PRIVILEGES|PROCEDURE|PROFILE|PROGRAM|PUBLIC|QUALIFIER|QUERY|QUERYNO|RANDOM|RANGE|RANK|RATIO_TO_REPORT|READ|READS|REAL|RECORDS|RECOVER|RECOVERDB|REF|REFERENCES|REFERENCING|REFRESH|REGENERATE|REGISTERS|RELATIVE|RELEASE|REMOVE|RENAME|REOPT|REORG|REPAIR|REPEAT|REPLACE|REQUIRED|RESET|RESIDENT|RESIGNAL|RESOLUTION|RESPECT|RESTART|RESTRICT|RESULT|RESULT_SET_LOCATOR|RETAIN|RETURN|RETURNED_SQLSTATE|RETURNING|RETURNS|REUSE|REVOKE|REXX|RIGHT|ROLE|ROLLBACK|ROLLUP|ROTATE|ROUNDING|ROUND_CEILING|ROUND_DOWN|ROUND_FLOOR|ROUND_HALF_DOWN|ROUND_HALF_EVEN|ROUND_HALF_UP|ROUND_UP|ROUTINE|ROW|ROWID|ROWS|ROWSET|ROW_COUNT|ROW_NUMBER|RR|RS|RULES|RUN|SAVEPOINT|SBCS|SCHEMA|SCHEME|SCRATCHPAD|SCROLL|SECOND|SECONDS|SECQTY|SECTION|SECURED|SECURITY|SEGSIZE|SELECT|SELECTIVITY|SENSITIVE|SEQUENCE|SERVAUTH|SERVER|SERVER_NAME|SESSION|SESSION_USER|SET|SETS|SHARE|SIGNAL|SIZE|SKIP|SMALLINT|SOME|SOURCE|SPACE|SPECIAL|SPECIFIC|SQL|SQLADM|SQLCA|SQLCODE|SQLD|SQLDA|SQLDABC|SQLERROR|SQLEXCEPTION|SQLID|SQLN|SQLSTATE|SQLVAR|SQLWARNING|STABILIZED|STACKED|START|STARTDB|STARTING|STATEMENT|STATEMENTS|STATIC|STATS|STAY|STDDEV|STMTCACHE|STMTID|STMTTOKEN|STOGROUP|STOP|STOPALL|STOPDB|STORAGE|STORCLAS|STORES|STOSPACE|STRUCTURE|STYLE|SUB|SUBSTR|SUBSTRING|SUM|SYNONYM|SYSADM|SYSCTRL|SYSDEFLT|SYSIBM|SYSOPR|SYSTEM|SYSTEM_TIME|TABLE|TABLESPACE|TEMPORAL|TEMPORARY|THEN|TIME|TIMESTAMP|TIMEZONE|TO|TOKEN|TRACE|TRACKMOD|TRANSACTION|TRANSFER|TRANSLATE|TRANSLATION|TRIGGER|TRIGGERS|TRIM|TRUNCATE|TRUSTED|TYPE|TYPES|UNBOUNDED|UNICODE|UNION|UNIQUE|UNNEST|UNPACK|UNTIL|UPDATE|UPON|UPPER|UR|URL|USA|USAGE|USE|USER|USERID|USING|V1|VALIDATE|VALIDPROC|VALUE|VALUES|VARBINARY|VARCHAR|VARGRAPHIC|VARIABLE|VARIANCE|VARYING|VCAT|VERSION|VERSIONING|VERSIONS|VIEW|VOLATILE|VOLUMES|WAIT|WAITFORDATA|WHEN|WHENEVER|WHERE|WHILE|WITH|WITHOUT|WLM|WORK|WORKFILE|WRAPPED|WRITE|WRKSTNNAME|XML|XMLCAST|XMLNAMESPACES|XMLPATTERN|XMLQUERY|XMLSCHEMA|XMLTABLE|YEAR|YEARS|YES|ZONE)(?![\\-\\w])",
		name: "keyword.verb.sql"
	},
	"cobol-preprocessor-keywords": {
		match: "(?<![\\-\\w])(?i:CBL|CONTROL|COPY|BY|CR|DB|END-EXEC|ENTER|EXEC|FILE|FUNCTION|IDMS|IN|INCLUDE|LEADING|LINKAGE|LIST|MAID|MAP|MAP-CONTROL|MODULE|NO|NOLIST|NOMAP|NOSOURCE|OF|OFF|PIC|PICTURE|RECORD|REDEFINES|REPLACING|REPLACE|TITLE|TRAILING|SECTION|SOURCE|SQL|SUPPRESS|VERSION)(?![\\-\\w])",
		name: "keyword.cobol"
	},
	"sql-block": {
		begin: "(?i:exec\\s+sql)",
		name: "string.quoted.cobol.sql",
		contentName: "meta.embedded.block.sql",
		patterns: [
			{
				include: "#db2-sql-keywords"
			},
			{
				include: "#comment-line"
			},
			{
				include: "#comment-floating"
			},
			{
				include: "#number-constant"
			},
			{
				include: "#string-quoted-constant"
			},
			{
				include: "#string-double-quoted-constant"
			}
		],
		end: "(?i:end\\-exec)\\.?"
	},
	"cics-block": {
		begin: "(?i:exec\\s+cics)",
		name: "string.quoted.cobol.cics",
		contentName: "meta.embedded.block.cics",
		patterns: [
			{
				include: "#cics-keywords"
			},
			{
				include: "#comment-line"
			},
			{
				include: "#comment-floating"
			},
			{
				include: "#number-constant"
			},
			{
				include: "#string-quoted-constant"
			},
			{
				include: "#string-double-quoted-constant"
			}
		],
		end: "(?i:end\\-exec)\\.?"
	}
};
var information_for_contributors = [
	"This file has been converted from https://github.com/eclipse/che-che4z-lsp-for-cobol/blob/master/clients/cobol-lsp-vscode-extension/",
	"If you want to provide a fix or improvement, please create a pull request against the original repository.",
	"Once accepted there, we are happy to receive an update request."
];
var COBOL_tmLanguage = {
	scopeName: scopeName,
	patterns: patterns,
	repository: repository,
	information_for_contributors: information_for_contributors
};

export { COBOL_tmLanguage as default, information_for_contributors, patterns, repository, scopeName };
