var name = "OCamllex";
var scopeName = "source.ocaml.ocamllex";
var fileTypes = [
	"mll"
];
var foldingStartMarker = "{";
var foldingStopMarker = "}";
var keyEquivalent = "^~O";
var patterns = [
	{
		include: "source.ocaml#comments"
	},
	{
		include: "source.ocaml#strings"
	},
	{
		include: "source.ocaml#characters"
	},
	{
		include: "#rules"
	},
	{
		include: "#keywords"
	},
	{
		include: "#actions"
	},
	{
		include: "#regex"
	},
	{
		match: "(’|‘|“|”)",
		name: "invalid.illegal.unrecognized-character.ocamllex"
	}
];
var repository = {
	rules: {
		match: "\\b(rule|and)[[:space:]]+([[:lower:]][[:word:]']*('|\\b))",
		captures: {
			"1": {
				name: "keyword.other.ocamllex"
			},
			"2": {
				name: "entity.name.function.rule.ocamllex"
			}
		}
	},
	keywords: {
		patterns: [
			{
				comment: "ocamllex reserved keywords",
				name: "keyword.other.ocamllex",
				match: "\\b(let|as|rule|and|parse|shortest|refill)\\b(?!')"
			},
			{
				comment: "assignment operator",
				match: "=",
				name: "keyword.operator.symbol.ocamllex"
			}
		]
	},
	actions: {
		patterns: [
			{
				comment: "embedded ocaml source",
				begin: "{",
				beginCaptures: [
					{
						name: "keyword.other.ocamllex"
					}
				],
				end: "}",
				endCaptures: [
					{
						name: "keyword.other.ocamllex"
					}
				],
				patterns: [
					{
						include: "source.ocaml"
					}
				]
			}
		]
	},
	regex: {
		patterns: [
			{
				comment: "regex character set",
				name: "punctuation.character-set.ocamllex",
				match: "\\[|\\]"
			},
			{
				comment: "regex group",
				name: "punctuation.group.ocamllex",
				match: "\\(|\\)"
			},
			{
				comment: "regex operators",
				name: "keyword.operator.ocamllex",
				match: "\\^|#|\\*|\\+|\\?|\\||-"
			},
			{
				comment: "end-of-file token",
				name: "constant.language.eof.ocamllex",
				match: "\\beof\\b"
			},
			{
				comment: "reference to regex pattern",
				name: "entity.name.type.reference.ocamllex",
				match: "\\b[[:alpha:]][[:word:]']*('|\\b)"
			}
		]
	}
};
var information_for_contributors = [
	"This file has been converted from https://github.com/ocamllabs/vscode-ocaml-platform/blob/master/",
	"If you want to provide a fix or improvement, please create a pull request against the original repository.",
	"Once accepted there, we are happy to receive an update request."
];
var ocamllex = {
	name: name,
	scopeName: scopeName,
	fileTypes: fileTypes,
	foldingStartMarker: foldingStartMarker,
	foldingStopMarker: foldingStopMarker,
	keyEquivalent: keyEquivalent,
	patterns: patterns,
	repository: repository,
	information_for_contributors: information_for_contributors
};

export { ocamllex as default, fileTypes, foldingStartMarker, foldingStopMarker, information_for_contributors, keyEquivalent, name, patterns, repository, scopeName };
